# --- containers.tcl --- Initialization script for the container package
#
# Copyright(C) I.B.Findleton, 2001. All Rights Reserved
#
# Get the correct form of the function name
#
proc Containers:GetFunctionName { name func } {

	if { [lindex [split $name :] 0] == "struct" } {
		return "-$func"
	} else {
		return $func
		}
	}
#
# Delete the dummy element if necessary
#
proc Containers:DeleteDummyElement { name } {

	global $name

	if { [info exists ${name}(*Dummy*)] } {
		unset ${name}(*Dummy*)
		}
	}
#
# Initialize an array from the current contents of a container
#
proc Containers:InitializeArray { name } {

	global $name

	catch { unset $name }

	set values [$name [Containers:GetFunctionName $name "list"]]

	foreach item $values {
		set ${name}([lindex $item 0]) [lindex $item 1]
		}

#	Containers:DeleteDummyElement $name

#	puts "Rewrote $name"
	}
#
# Uninitialize an array
#
proc Containers:UninitializeArray { name } {

# Get rid of the array variable

	catch { unset $name }
	}
#
# Update an array if necessary
#
proc Containers:UpdateArray { name } {

	set func [Containers:GetFunctionName $name "status"]

	if { [$name $func] != "clean" } {
		Containers:InitializeArray $name
		$name $func clean
		}
	}
#
# Update an element of the array if necessary
#
proc Containers:UpdateArrayElement { name index } {

	global $name

	set func [Containers:GetFunctionName $name "get"]
	set stat [Containers:GetFunctionName $name "status"]

	if { [$name $stat] == "dirty" } {
		set ${name}($index) [$name $func $index]
		}

	Containers:DeleteDummyElement $name
	}
