#!/bin/sh
# \
exec tclsh "$0" ${1+"$@"}

# --- struct.tcl --- Test harness for structures
#
# Copyright(C) I.B.Findleton, 2001. All Rights Reserved

package require Containers

# Create a template of a structure that contains basic data on a person

set person [struct Name Address Phone]

# Create 3 instances of the structure and initialize them with data

set a [$person  "Iain B. Findleton" "18 Watterson" "457-0744"]
set b [$person  "Walter Ross Mayor Findleton" "47 SummerHill"  "695-4022"]
set c [$person "Anne-Marie Beaubien" "18 Watterson" "457-0748"]

# Load the structures into a random queue

set q [rqueue]
$q add $a $b $c

# Print out the stucture data in the queue order

while { [$q count] } {
	set who [$q next]
	puts "[$who Name] [$who Address] [$who Phone]"
	}

$q destroy

# List the contents of one of the structure instances

puts "Elements [$a -elements]"
puts "Values [$a -keys]"
puts "List [$a -list]"

# Create a new template adding another element to the original one

set bus [struct $person Business]

puts "\nBus Elements \n[$bus -elements]"

# Create and initialize an instance of the new structure from the original
# one and add a new value for the new element

set d [$bus $a "979-0297"]

puts "\nIain's Record \n[$d -list]"

# Create an empty structure instance

set e [$person ""]

# Initialization from an existing instance

$e = $a

puts "\nAssignement \n[$e -list]"

# Append the data from another instance

$e += $b

puts "\nAppend \n[$e -list]"

# Embedded structures

set f [struct [list Iain $person] [list Ross $person] [list Anne-Marie $person]]

puts "\nElements of $f ...\n[$f -elements]"

# Create an empty instance of the tmplate
  
set g [$f ""]

# Initialize the instance from previously initialized structure instances

$g = [list Iain $a] [list Ross $b] [list  Anne-Marie $c]

puts "\nData...\n[$g -list]"

puts "\nTest OK\n"


