#!/bin/sh
# \
exec tclsh "$0" ${1+"$@"}
#
# --- torture.tcl --- Tests for the containers package
#
# This script will run some basic tests on the various containers
# that are provided by the Containers package.
#
# Copyright(C) I.B.Findleton, 2001. All Rights Reserved
#

package require Containers

# Test the queue

puts stdout "\nTesting a queue..."

set q [queue -size 50]
for { set i 0 } { $i < 10 } { incr i } {
	$q insert "String $i"
	}

puts stdout "Queue has [$q length] elements"

puts stdout "[$q list]"

foreach i { 1 6 4 8 } {
	puts stdout "Index $i [$q get $i]"
	}

puts stdout "Queue has [$q length] elements"

puts stdout "[$q list]"

$q destroy

# Test the stack

puts stdout "\nTesting the stack..."

set s [stack]
foreach i { 1 2 3 4 5 6 7 8 9 } { $s push "String $i" }
puts stdout "Stack length [$s count]"
puts stdout "Stack contents\n[$s list]"
while { [$s count] != 0 } {
	puts stdout "[$s pop]"
	}

$s destroy

# Test the tree

puts stdout "\nTesting the tree..."

proc SortedList { args } {

	set t [ eval { tree } $args]
	foreach i { n p r w l g n a n s y h b v h z o } { $t add $i }
	puts stdout "Tree length [$t count]"
	puts "Tree contents\n[$t list]"

	$t destroy
	}

puts stdout "\nSorted with duplicates allowed..."

SortedList

puts stdout "\nSorted with no duplicates allowed..."

SortedList -unique true

puts stdout "\nSorted in reverse order..."

SortedList -reverse true

puts stdout "\nTesting the priority queue..."

proc PriorityQueue { args } {

	set p [eval { pqueue } $args]
	foreach i { 1 10 44 6 21 18 -3 } { $p add $i "String $i" }
	puts stdout "Queue length [$p count]"
	puts stdout "Queue contents\n[$p list]"

	$p destroy
	}

puts stdout "\nSort using string collating sequence..."

PriorityQueue 

puts stdout "\nSort using the numeric value of the key..."

PriorityQueue -priority numeric

puts stdout "\nSort in reverse order by numeric value..."

PriorityQueue -priority numeric -reverse true




