#!/bin/sh
# \
exec tclsh "$0" ${1+"$@"}

# --- tree.tcl --- Test harness for tree based containers
#
# Copyright(C) I.B.Findleton, 2001. All Rights Reserved

package require Containers

# A simple binary tree container sorts in collating sequence

set t [tree]

for { set i 0 } { $i < 10 } { incr i } { $t add "String [expr int(rand() * 100)]" }

puts "Sorted Tree...\n[$t list]"

# A priority queue using numbers for the priority values

set q [pqueue -priority numeric]

for { set i 0 } { $i < 10 } { incr i } { 
	$q add [expr int(rand() * 100)] "String $i"
	}

puts "\nPriority Queue...\n[$q list]"

# A random queue stores values in random order

set r [rqueue]

for { set i 0 } { $i < 10 } { incr i } { $r add "String $i" }

puts "\nRandom Queue...\n[$r list]"

# A tree that sorts things in a peculiar fashion. Items can have optional
# attributes indicated by a leading @,+ or * character.

set a [tree -alphabet "@+*" -reverse true]

foreach item { Ross @Iain @+Emilie +Julie @David +Anne-Marie Derek +Amber *Daniel *+Ashley } {
		$a add $item
		}

puts "\nA queue of items with attributes...\n[$a list]"



